@@ -22,7 +22,7 @@ def macro_china_yearly_cpi_index():
 
     return csc.macro_china_yearly_cpi_fixed_base_idx()
 
-def macro_china_monthy_cpi_yoy():
+def macro_china_monthly_cpi_yoy():
 
     csc = CStatsCrawler()
 
