@@ -1,5 +1,6 @@
 # -*- coding:utf-8 -*-
 
+import pandas as pd
 
 from hawkdata.utils.crawlers import CStatsCrawler
 
@@ -14,7 +15,13 @@ def macro_china_yearly_gdp_yoy():
 
     csc = CStatsCrawler()
 
-    return csc.macro_china_yearly_gdp_yoy()
+    gdp_idx_df = csc.macro_china_yearly_gdp_idx()
+    gdp_yoy_df = gdp_idx_df.rename(columns={
+        'gdp_idx': 'gdp_yoy'
+    })
+    gdp_yoy_df['gdp_yoy'] = gdp_yoy_df['gdp_yoy'].apply(lambda x: (x/100)-1)
+
+    return gdp_yoy_df
 
 def macro_china_yearly_gdp_index():
 
@@ -31,5 +38,10 @@ def macro_china_quarterly_gdp():
 def macro_china_quarterly_gdp_yoy():
 
     csc = CStatsCrawler()
+    gdp_idx_df = csc.macro_china_quarterly_gdp_idx()
+    gdp_yoy_df = gdp_idx_df.rename(columns={
+        'gdp_idx': 'gdp_yoy'
+    })
+    gdp_yoy_df['gdp_yoy'] = gdp_yoy_df['gdp_yoy'].apply(lambda x: (x/100)-1)
 
-    return csc.macro_china_quarterly_gdp_yoy()
+    return gdp_yoy_df
