@@ -17,3 +17,9 @@ CbCrawler = cb_crawler.CbCrawler
 
 from hawkdata.utils.crawlers import cstats_crawler
 CStatsCrawler = cstats_crawler.CStatsCrawler
+
+from hawkdata.utils.crawlers import csidx_crawler
+CsIdxCrawler = csidx_crawler.CsIdxCrawler
+
+from hawkdata.utils.crawlers import cnidx_crawler
+CnIdxCrawler = cnidx_crawler.CnIdxCrawler
